==> ultra-erp-clean-v2.1.zip: src/Views/inventory/adjust/index.php <==
<h5>Ombor — Kirim (IN)</h5>
<div class="card p-2 mb-2">
  <form method="post" action="?r=inventory/adjust/in" class="row row-cols-1 row-cols-md-6 g-2">
    <div class="col"><label class="form-label">Sana</label><input type="date" class="form-control form-control-sm" name="date" required></div>
    <div class="col"><label class="form-label">Ombor</label><select class="form-select form-select-sm" name="warehouse_id"><?php foreach($whs as $w): ?><option value="<?=$w['id']?>"><?=$w['code']?> — <?=$w['name']?></option><?php endforeach; ?></select></div>
    <div class="col"><label class="form-label">Mahsulot</label><select class="form-select form-select-sm" name="product_id"><?php foreach($prod as $p): ?><option value="<?=$p['id']?>"><?=$p['code']?> — <?=$p['name']?></option><?php endforeach; ?></select></div>
    <div class="col"><label class="form-label">Miqdor</label><input class="form-control form-control-sm" type="number" step="0.001" name="qty" value="1" required></div>
    <div class="col"><label class="form-label">Birlik narx</label><input class="form-control form-control-sm" type="number" step="0.01" name="unit_cost" value="0" required></div>
    <div class="col align-self-end"><button class="btn btn-primary btn-sm">Saqlash</button></div>
  </form>
</div>
<table class="table table-sm table-hover"><thead><tr><th>Sana</th><th>Mahsulot</th><th>Ombor</th><th class="text-end">Miqdor</th><th class="text-end">Summa</th><th>Tur</th></tr></thead><tbody>
<?php foreach($rows as $r): ?><tr><td><?=$r['date']?></td><td><?=$r['pcode']?> — <?=$r['pname']?></td><td><?=$r['warehouse_id']?></td><td class="text-end"><?=$r['qty']?></td><td class="text-end"><?=$r['amount']?></td><td><?=$r['type']?></td></tr><?php endforeach; ?></tbody></table>

==> ultra-erp-clean-v2.2.zip: src/Views/inventory/adjust/index.php <==
<h5>Ombor — Kirim (IN)</h5>
<div class="card p-2 mb-2">
  <form method="post" action="<?= \App\Core\Response::url(\'\1\') ?>" class="row row-cols-1 row-cols-md-6 g-2">
    <div class="col"><label class="form-label">Sana</label><input type="date" class="form-control form-control-sm" name="date" required></div>
    <div class="col"><label class="form-label">Ombor</label><select class="form-select form-select-sm" name="warehouse_id"><?php foreach($whs as $w): ?><option value="<?=$w['id']?>"><?=$w['code']?> — <?=$w['name']?></option><?php endforeach; ?></select></div>
    <div class="col"><label class="form-label">Mahsulot</label><select class="form-select form-select-sm" name="product_id"><?php foreach($prod as $p): ?><option value="<?=$p['id']?>"><?=$p['code']?> — <?=$p['name']?></option><?php endforeach; ?></select></div>
    <div class="col"><label class="form-label">Miqdor</label><input class="form-control form-control-sm" type="number" step="0.001" name="qty" value="1" required></div>
    <div class="col"><label class="form-label">Birlik narx</label><input class="form-control form-control-sm" type="number" step="0.01" name="unit_cost" value="0" required></div>
    <div class="col align-self-end"><button class="btn btn-primary btn-sm">Saqlash</button></div>
  </form>
</div>
<table class="table table-sm table-hover"><thead><tr><th>Sana</th><th>Mahsulot</th><th>Ombor</th><th class="text-end">Miqdor</th><th class="text-end">Summa</th><th>Tur</th></tr></thead><tbody>
<?php foreach($rows as $r): ?><tr><td><?=$r['date']?></td><td><?=$r['pcode']?> — <?=$r['pname']?></td><td><?=$r['warehouse_id']?></td><td class="text-end"><?=$r['qty']?></td><td class="text-end"><?=$r['amount']?></td><td><?=$r['type']?></td></tr><?php endforeach; ?></tbody></table>
